@@ -1,6 +1,6 @@
 /*
  * json_stats.h: Include file used to display system statistics in JSON format.
- * (C) 1999-2018 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2019 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _JSON_STATS_H
@@ -14,7 +14,7 @@
  ***************************************************************************
  */
 
-/* Functions used to display statistics in JSON */
+/* Functions used to display statistics in XML */
 __print_funct_t json_print_cpu_stats
 	(struct activity *, int, int, unsigned long long);
 __print_funct_t json_print_pcsw_stats
@@ -94,4 +94,4 @@ __print_funct_t json_print_fchost_stats
 __print_funct_t json_print_softnet_stats
 	(struct activity *, int, int, unsigned long long);
 
-#endif /* _JSON_STATS_H */
+#endif /* _XML_STATS_H */
