@@ -1,6 +1,6 @@
 /*
  * mpstat: per-processor statistics
- * (C) 2000-2018 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2000-2019 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -652,7 +652,6 @@ void write_json_cpu_stats(int tab, unsigned long long deltot_jiffies, int prev,
 			  unsigned char offline_cpu_bitmap[])
 {
 	int i, next = FALSE;
-	char cpu_name[16];
 	struct stats_cpu *scc, *scp;
 
 	xprintf(tab++, "\"cpu-load\": [");
@@ -676,15 +675,7 @@ void write_json_cpu_stats(int tab, unsigned long long deltot_jiffies, int prev,
 		}
 		next = TRUE;
 
-		if (i == 0) {
-			/* This is CPU "all" */
-			strcpy(cpu_name, "all");
-
-		}
-		else {
-			snprintf(cpu_name, 16, "%d", i - 1);
-			cpu_name[15] = '\0';
-
+		if (i != 0) {
 			/* Recalculate itv for current proc */
 			deltot_jiffies = get_per_cpu_interval(scc, scp);
 
@@ -703,9 +694,9 @@ void write_json_cpu_stats(int tab, unsigned long long deltot_jiffies, int prev,
 			}
 		}
 
-		xprintf0(tab, "{\"cpu\": \"%s\", \"usr\": %.2f, \"nice\": %.2f, \"sys\": %.2f, "
+		xprintf0(tab, "{\"cpu\": \"%d\", \"usr\": %.2f, \"nice\": %.2f, \"sys\": %.2f, "
 			 "\"iowait\": %.2f, \"irq\": %.2f, \"soft\": %.2f, \"steal\": %.2f, "
-			 "\"guest\": %.2f, \"gnice\": %.2f, \"idle\": %.2f}", cpu_name,
+			 "\"guest\": %.2f, \"gnice\": %.2f, \"idle\": %.2f}", i - 1,
 			 (scc->cpu_user - scc->cpu_guest) < (scp->cpu_user - scp->cpu_guest) ?
 			 0.0 :
 			 ll_sp_value(scp->cpu_user - scp->cpu_guest,
@@ -1880,10 +1871,12 @@ void rw_mpstat_loop(int dis_hdr, int rows)
 		       STATS_IRQCPU_SIZE * (cpu_nr + 1) * softirqcpu_nr);
 	}
 
-	/* Set a handler for SIGINT */
-	memset(&int_act, 0, sizeof(int_act));
-	int_act.sa_handler = int_handler;
-	sigaction(SIGINT, &int_act, NULL);
+	if (!DISPLAY_JSON_OUTPUT(flags)) {
+		/* Set a handler for SIGINT */
+		memset(&int_act, 0, sizeof(int_act));
+		int_act.sa_handler = int_handler;
+		sigaction(SIGINT, &int_act, NULL);
+	}
 
 	pause();
 
@@ -1939,16 +1932,17 @@ void rw_mpstat_loop(int dis_hdr, int rows)
 
 		if (count) {
 
+			if (DISPLAY_JSON_OUTPUT(flags)) {
+				printf(",\n");
+			}
 			pause();
 
 			if (sigint_caught) {
 				/* SIGINT signal caught => Display average stats */
 				count = 0;
+				printf("\n");	/* Skip "^C" displayed on screen */
 			}
 			else {
-				if (DISPLAY_JSON_OUTPUT(flags)) {
-					printf(",\n");
-				}
 				curr ^= 1;
 			}
 		}
