@@ -1,6 +1,6 @@
 /*
  * sar/sadc: Report system activity
- * (C) 1999-2018 by Sebastien Godard (sysstat <at> orange.fr)
+ * (C) 1999-2019 by Sebastien Godard (sysstat <at> orange.fr)
  */
 
 #ifndef _SA_H
@@ -110,6 +110,7 @@
 #define S_F_HUMAN_READ		0x01000000
 #define S_F_ZERO_OMIT		0x02000000
 #define S_F_SVG_SHOW_TOC	0x04000000
+#define S_F_FDATASYNC		0x08000000
 
 #define WANT_SINCE_BOOT(m)		(((m) & S_F_SINCE_BOOT)   == S_F_SINCE_BOOT)
 #define WANT_SA_ROTAT(m)		(((m) & S_F_SA_ROTAT)     == S_F_SA_ROTAT)
@@ -139,6 +140,7 @@
 #define PACK_VIEWS(m)			(((m) & S_F_SVG_PACKED) == S_F_SVG_PACKED)
 #define DISPLAY_HUMAN_READ(m)		(((m) & S_F_HUMAN_READ) == S_F_HUMAN_READ)
 #define DISPLAY_TOC(m)			(((m) & S_F_SVG_SHOW_TOC) == S_F_SVG_SHOW_TOC)
+#define FDATASYNC(m)			(((m) & S_F_FDATASYNC)    == S_F_FDATASYNC)
 
 #define AO_F_NULL		0x00000000
 
@@ -224,6 +226,11 @@
 #define K_HEIGHT	"height="
 #define K_PACKED	"packed"
 #define K_SHOWTOC	"showtoc"
+#define K_CUSTOMCOL	"customcol"
+#define K_BWCOL		"bwcol"
+
+/* Environment variables */
+#define ENV_COLORS_PALETTE	"S_COLORS_PALETTE"
 
 /* Groups of activities */
 #define G_DEFAULT	0x00
@@ -1100,6 +1107,23 @@ struct report_format {
 /* Maximum number of horizontal lines for the background grid */
 #define MAX_HLINES_NR	10
 
+/* Color palette constants */
+#define SVG_COLORS_IDX_MASK	0x0f
+#define SVG_COL_PALETTE_SIZE	24
+#define SVG_COL_PALETTE_NR	3
+#define SVG_COL_BCKGRD_IDX	16
+#define SVG_COL_AXIS_IDX	17
+#define SVG_COL_GRID_IDX	18
+#define SVG_COL_TITLE_IDX	19
+#define SVG_COL_INFO_IDX	20
+#define SVG_COL_DEFAULT_IDX	21
+#define SVG_COL_HEADER_IDX	22
+#define SVG_COL_ERROR_IDX	23
+
+#define SVG_DEFAULT_COL_PALETTE	0
+#define SVG_CUSTOM_COL_PALETTE	1
+#define SVG_BW_COL_PALETTE	2
+
 #define MAYBE	0x80
 
 /*
@@ -1326,6 +1350,8 @@ void get_global_soft_statistics
 	(struct activity *, int, int, unsigned int, unsigned char []);
 void get_itv_value
 	(struct record_header *, struct record_header *, unsigned long long *);
+void init_custom_color_palette
+	(void);
 int next_slice
 	(unsigned long long, unsigned long long, int, long);
 void parse_sa_devices
