@@ -1,6 +1,6 @@
 /*
  * sadf: system activity data formatter
- * (C) 1999-2018 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2019 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -51,6 +51,8 @@ int endian_mismatch = FALSE;
 int arch_64 = FALSE;
 /* Number of decimal places */
 int dplaces_nr = -1;
+/* Color palette number */
+int palette = SVG_DEFAULT_COL_PALETTE;
 
 unsigned int flags = 0;
 unsigned int dm_major;		/* Device-mapper major number */
@@ -1293,6 +1295,9 @@ void logic3_display_loop(int ifd, struct file_activity *file_actlst,
 	/* Use a decimal point to make SVG code locale independent */
 	setlocale(LC_NUMERIC, "C");
 
+	/* Init custom colors palette */
+	init_custom_color_palette();
+
 	/*
 	 * Calculate the number of rows and the max number of views per row to display.
 	 * Result may be 0. In this case, "No data" will be displayed instead of the graphs.
@@ -1566,6 +1571,12 @@ int main(int argc, char **argv)
 				else if (!strcmp(t, K_SHOWTOC)) {
 					flags |= S_F_SVG_SHOW_TOC;
 				}
+				else if (!strcmp(t, K_CUSTOMCOL)) {
+					palette = SVG_CUSTOM_COL_PALETTE;
+				}
+				else if (!strcmp(t, K_BWCOL)) {
+					palette = SVG_BW_COL_PALETTE;
+				}
 				else {
 					usage(argv[0]);
 				}
