@@ -1,6 +1,6 @@
 /*
  * sadf_misc.c: Funtions used by sadf to display special records
- * (C) 2011-2018 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 2011-2019 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -35,6 +35,8 @@
 extern unsigned int flags;
 extern char *seps[];
 
+extern int palette;
+extern unsigned int svg_colors[][SVG_COL_PALETTE_SIZE];
 
 /*
  ***************************************************************************
@@ -954,9 +956,11 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile,
 			height = 100;
 		}
 		printf(" width=\"%d\" height=\"%d\""
-		       " fill=\"black\" stroke=\"gray\" stroke-width=\"1\">\n",
-		       SVG_T_XSIZE * (hdr_parm->views_per_row), height);
-		printf("<text x=\"0\" y=\"30\" text-anchor=\"start\" stroke=\"brown\">");
+		       " fill=\"black\" stroke=\"#%06x\" stroke-width=\"1\">\n",
+		       SVG_T_XSIZE * (hdr_parm->views_per_row), height,
+		       svg_colors[palette][SVG_COL_DEFAULT_IDX]);
+		printf("<text x=\"0\" y=\"30\" text-anchor=\"start\" stroke=\"#%06x\">",
+		       svg_colors[palette][SVG_COL_HEADER_IDX]);
 		print_gal_header(localtime_r((const time_t *) &(file_hdr->sa_ust_time), &rectime),
 				 file_hdr->sa_sysname, file_hdr->sa_release,
 				 file_hdr->sa_nodename, file_hdr->sa_machine,
@@ -985,9 +989,10 @@ __printf_funct_t print_svg_header(void *parm, int action, char *dfile,
 		if (!(action & F_BEGIN)) {
 			if (!hdr_parm->graph_nr) {
 				/* No views displayed */
-				printf("<text x= \"0\" y=\"%d\" text-anchor=\"start\" stroke=\"red\">",
+				printf("<text x= \"0\" y=\"%d\" text-anchor=\"start\" stroke=\"#%06x\">",
 				       SVG_H_YSIZE +
-				       SVG_C_YSIZE * (DISPLAY_TOC(flags) ? hdr_parm->nr_act_dispd : 0));
+				       SVG_C_YSIZE * (DISPLAY_TOC(flags) ? hdr_parm->nr_act_dispd : 0),
+				       svg_colors[palette][SVG_COL_ERROR_IDX]);
 				printf("No data!</text>\n");
 			}
 			/* Give actual SVG height */
@@ -1146,3 +1151,68 @@ __nr_t count_new_disk(struct activity *a, int curr)
 
 	return nr;
 }
+
+/*
+ ***************************************************************************
+ * Init custom color palette used to draw graphs (sadf -g).
+ ***************************************************************************
+ */
+void init_custom_color_palette()
+{
+	char *e, *p;
+	int len;
+	unsigned int val;
+
+	/* Read S_COLORS_PALETTE environment variable */
+	if ((e = getenv(ENV_COLORS_PALETTE)) == NULL)
+		/* Environment variable not set */
+		return;
+
+	for (p = strtok(e, ":"); p; p =strtok(NULL, ":")) {
+
+		len = strlen(p);
+		if ((len > 8) || (len < 3) || (*(p + 1) != '=') ||
+		    (strspn(p + 2, "0123456789ABCDEFabcdef") != (len - 2)))
+			/* Ignore malformed codes */
+			continue;
+
+		sscanf(p + 2, "%x", &val);
+
+		if ((*p >= '0') && (*p <= '9')) {
+			svg_colors[SVG_CUSTOM_COL_PALETTE][*p & 0xf] = val;
+			continue;
+		}
+		else if (((*p >= 'A') && (*p <= 'F')) ||
+			 ((*p >= 'a') && (*p <= 'f'))) {
+			svg_colors[SVG_CUSTOM_COL_PALETTE][9 + (*p & 0xf)] = val;
+			continue;
+		}
+
+		switch (*p) {
+			case 'G':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_GRID_IDX] = val;
+				break;
+			case 'H':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_HEADER_IDX] = val;
+				break;
+			case 'I':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_INFO_IDX] = val;
+				break;
+			case 'K':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_BCKGRD_IDX] = val;
+				break;
+			case 'L':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_DEFAULT_IDX] = val;
+				break;
+			case 'T':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_TITLE_IDX] = val;
+				break;
+			case 'W':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_ERROR_IDX] = val;
+				break;
+			case 'X':
+				svg_colors[SVG_CUSTOM_COL_PALETTE][SVG_COL_AXIS_IDX] = val;
+				break;
+		}
+	}
+}
